pipi
====

install & save functionality for pip.

Usage
~~~~~

::

    pipi package_name
    like 'pip install package_name && pip freeze > requirements.txt'


Installation
~~~~~~~~~~~~

::

    pip install pipi
